@@ -1,13 +1,17 @@
+"""
+This example demonstrates how to use Pinecone with Langtrace.
+"""
 from dotenv import find_dotenv, load_dotenv
-from init import init
 from openai import OpenAI
 from pinecone import Pinecone
-from utils.with_root_span import with_langtrace_root_span
 
+from src.langtrace_python_sdk import langtrace
+from src.utils.with_root_span import with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
 
-init()
+langtrace.init(batch=True, log_spans_to_console=True,
+               write_to_remote_url=False)
 
 client = OpenAI()
 pinecone = Pinecone()
