@@ -1,11 +1,10 @@
 import json
 
 from langtrace.trace_attributes import FrameworkSpanAttributes
-from opentelemetry.trace import SpanKind, StatusCode
+from opentelemetry.trace import SpanKind
 from opentelemetry.trace.status import Status, StatusCode
 
-from constants.instrumentation.common import SERVICE_PROVIDERS
-
+from src.constants.instrumentation.common import SERVICE_PROVIDERS
 
 
 def generic_patch(method_name, task, tracer, version, trace_output=True, trace_input=True):
